==> aws-sdk-cpp-1.9.365-1-x86_64.pkg.tar.zst: usr/include/aws/pinpoint/model/UpdateApnsVoipSandboxChannelRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/pinpoint/Pinpoint_EXPORTS.h>
#include <aws/pinpoint/PinpointRequest.h>
#include <aws/pinpoint/model/APNSVoipSandboxChannelRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Pinpoint
{
namespace Model
{

  /**
   */
  class AWS_PINPOINT_API UpdateApnsVoipSandboxChannelRequest : public PinpointRequest
  {
  public:
    UpdateApnsVoipSandboxChannelRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "UpdateApnsVoipSandboxChannel"; }

    Aws::String SerializePayload() const override;


    
    inline const APNSVoipSandboxChannelRequest& GetAPNSVoipSandboxChannelRequest() const{ return m_aPNSVoipSandboxChannelRequest; }

    
    inline bool APNSVoipSandboxChannelRequestHasBeenSet() const { return m_aPNSVoipSandboxChannelRequestHasBeenSet; }

    
    inline void SetAPNSVoipSandboxChannelRequest(const APNSVoipSandboxChannelRequest& value) { m_aPNSVoipSandboxChannelRequestHasBeenSet = true; m_aPNSVoipSandboxChannelRequest = value; }

    
    inline void SetAPNSVoipSandboxChannelRequest(APNSVoipSandboxChannelRequest&& value) { m_aPNSVoipSandboxChannelRequestHasBeenSet = true; m_aPNSVoipSandboxChannelRequest = std::move(value); }

    
    inline UpdateApnsVoipSandboxChannelRequest& WithAPNSVoipSandboxChannelRequest(const APNSVoipSandboxChannelRequest& value) { SetAPNSVoipSandboxChannelRequest(value); return *this;}

    
    inline UpdateApnsVoipSandboxChannelRequest& WithAPNSVoipSandboxChannelRequest(APNSVoipSandboxChannelRequest&& value) { SetAPNSVoipSandboxChannelRequest(std::move(value)); return *this;}


    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline const Aws::String& GetApplicationId() const{ return m_applicationId; }

    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline bool ApplicationIdHasBeenSet() const { return m_applicationIdHasBeenSet; }

    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline void SetApplicationId(const Aws::String& value) { m_applicationIdHasBeenSet = true; m_applicationId = value; }

    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline void SetApplicationId(Aws::String&& value) { m_applicationIdHasBeenSet = true; m_applicationId = std::move(value); }

    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline void SetApplicationId(const char* value) { m_applicationIdHasBeenSet = true; m_applicationId.assign(value); }

    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline UpdateApnsVoipSandboxChannelRequest& WithApplicationId(const Aws::String& value) { SetApplicationId(value); return *this;}

    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline UpdateApnsVoipSandboxChannelRequest& WithApplicationId(Aws::String&& value) { SetApplicationId(std::move(value)); return *this;}

    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline UpdateApnsVoipSandboxChannelRequest& WithApplicationId(const char* value) { SetApplicationId(value); return *this;}

  private:

    APNSVoipSandboxChannelRequest m_aPNSVoipSandboxChannelRequest;
    bool m_aPNSVoipSandboxChannelRequestHasBeenSet = false;

    Aws::String m_applicationId;
    bool m_applicationIdHasBeenSet = false;
  };

} // namespace Model
} // namespace Pinpoint
} // namespace Aws

==> aws-sdk-cpp-1.11.476-1-x86_64.pkg.tar.zst: usr/include/aws/pinpoint/model/UpdateApnsVoipSandboxChannelRequest.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/pinpoint/Pinpoint_EXPORTS.h>
#include <aws/pinpoint/PinpointRequest.h>
#include <aws/pinpoint/model/APNSVoipSandboxChannelRequest.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Pinpoint
{
namespace Model
{

  /**
   */
  class UpdateApnsVoipSandboxChannelRequest : public PinpointRequest
  {
  public:
    AWS_PINPOINT_API UpdateApnsVoipSandboxChannelRequest();

    // Service request name is the Operation name which will send this request out,
    // each operation should has unique request name, so that we can get operation's name from this request.
    // Note: this is not true for response, multiple operations may have the same response name,
    // so we can not get operation's name from response.
    inline virtual const char* GetServiceRequestName() const override { return "UpdateApnsVoipSandboxChannel"; }

    AWS_PINPOINT_API Aws::String SerializePayload() const override;


    ///@{
    
    inline const APNSVoipSandboxChannelRequest& GetAPNSVoipSandboxChannelRequest() const{ return m_aPNSVoipSandboxChannelRequest; }
    inline bool APNSVoipSandboxChannelRequestHasBeenSet() const { return m_aPNSVoipSandboxChannelRequestHasBeenSet; }
    inline void SetAPNSVoipSandboxChannelRequest(const APNSVoipSandboxChannelRequest& value) { m_aPNSVoipSandboxChannelRequestHasBeenSet = true; m_aPNSVoipSandboxChannelRequest = value; }
    inline void SetAPNSVoipSandboxChannelRequest(APNSVoipSandboxChannelRequest&& value) { m_aPNSVoipSandboxChannelRequestHasBeenSet = true; m_aPNSVoipSandboxChannelRequest = std::move(value); }
    inline UpdateApnsVoipSandboxChannelRequest& WithAPNSVoipSandboxChannelRequest(const APNSVoipSandboxChannelRequest& value) { SetAPNSVoipSandboxChannelRequest(value); return *this;}
    inline UpdateApnsVoipSandboxChannelRequest& WithAPNSVoipSandboxChannelRequest(APNSVoipSandboxChannelRequest&& value) { SetAPNSVoipSandboxChannelRequest(std::move(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>The unique identifier for the application. This identifier is displayed as
     * the <b>Project ID</b> on the Amazon Pinpoint console.</p>
     */
    inline const Aws::String& GetApplicationId() const{ return m_applicationId; }
    inline bool ApplicationIdHasBeenSet() const { return m_applicationIdHasBeenSet; }
    inline void SetApplicationId(const Aws::String& value) { m_applicationIdHasBeenSet = true; m_applicationId = value; }
    inline void SetApplicationId(Aws::String&& value) { m_applicationIdHasBeenSet = true; m_applicationId = std::move(value); }
    inline void SetApplicationId(const char* value) { m_applicationIdHasBeenSet = true; m_applicationId.assign(value); }
    inline UpdateApnsVoipSandboxChannelRequest& WithApplicationId(const Aws::String& value) { SetApplicationId(value); return *this;}
    inline UpdateApnsVoipSandboxChannelRequest& WithApplicationId(Aws::String&& value) { SetApplicationId(std::move(value)); return *this;}
    inline UpdateApnsVoipSandboxChannelRequest& WithApplicationId(const char* value) { SetApplicationId(value); return *this;}
    ///@}
  private:

    APNSVoipSandboxChannelRequest m_aPNSVoipSandboxChannelRequest;
    bool m_aPNSVoipSandboxChannelRequestHasBeenSet = false;

    Aws::String m_applicationId;
    bool m_applicationIdHasBeenSet = false;
  };

} // namespace Model
} // namespace Pinpoint
} // namespace Aws
